#
# spec file for package python-khal
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-khal
Version:        0.13.0
Release:        1.1
Summary:        CLI calendar with CalDAV support
License:        MIT
URL:            https://lostpackets.de/khal/
Source0:        https://files.pythonhosted.org/packages/source/k/khal/khal-%{version}.tar.gz
BuildRequires:  %{python_module aiohttp}
BuildRequires:  %{python_module click >= 3.2}
BuildRequires:  %{python_module click-log >= 0.2.0}
BuildRequires:  %{python_module configobj}
BuildRequires:  %{python_module dateutil}
BuildRequires:  %{python_module freezegun}
BuildRequires:  %{python_module hypothesis}
BuildRequires:  %{python_module icalendar >= 6.0.0}
BuildRequires:  %{python_module packaging}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pytz}
BuildRequires:  %{python_module pyxdg}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module tzlocal >= 1.0}
BuildRequires:  %{python_module urwid >= 2.6.15}
BuildRequires:  %{python_module urwid >= 2.6.15}
BuildRequires:  %{python_module vdirsyncer}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-click
Requires:       python-click-log
Requires:       python-configobj
Requires:       python-icalendar >= 6.0.0
Requires:       python-python-dateutil
Requires:       python-pytz >= 2018
Requires:       python-pyxdg
Requires:       python-tzlocal
Requires:       python-urwid
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
Khal is a CLI (console), CalDAV based calendar program, allowing syncing of
calendars with a variety of other programs on a host of different platforms.

%package -n python-khal-bash-completion
Summary:        Bash completion for khal
Requires:       bash-completion
Supplements:    (khal and bash-completion)
BuildArch:      noarch

%description -n python-khal-bash-completion
Bash shell completions for khal

%package -n python-khal-fish-completion
Summary:        Fish completion for khal
Requires:       fish
Supplements:    (khal and fish)
BuildArch:      noarch

%description -n python-khal-fish-completion
Fish shell completions for khal

%package -n python-khal-zsh-completion
Summary:        ZSH completion for khal
Supplements:    (khal and zsh)
BuildArch:      noarch

%description -n python-khal-zsh-completion
zsh shell completions for khal

%prep
%autosetup -p1 -n khal-%{version}

%build
%pyproject_wheel

for shell in bash zsh fish; do
    PYTHONPATH="$PWD" _KHAL_COMPLETE=${shell}_source python3 ./bin/khal >khal.$shell
done

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/khal
%python_clone -a %{buildroot}%{_bindir}/ikhal
%python_expand %fdupes %{buildroot}%{$python_sitelib}

install -Dm644 khal.bash \
    %{buildroot}%{_datadir}/bash-completion/completions/khal
install -Dm644 khal.zsh \
    %{buildroot}%{_datadir}/zsh/site-functions/_khal
install -Dm644 khal.fish \
    %{buildroot}%{_datadir}/fish/vendor_completions.d/khal.fish

%check
# Requires /dev/tty working
# https://github.com/pimutils/khal/issues/683
donttest="test_import_from_stdin"
# Broken tests with latest pytz versions
donttest+=" or test_bogota or test_event_no_dst"
%pytest -k "not (${donttest})"

%post
%python_install_alternative khal
%python_install_alternative ikhal

%postun
%python_uninstall_alternative khal
%python_uninstall_alternative ikhal

%files %{python_files}
%license COPYING
%doc AUTHORS.txt CONTRIBUTING.rst README.rst khal.conf.sample
%{python_sitelib}/khal
%{python_sitelib}/khal-%{version}.dist-info
%python_alternative %{_bindir}/khal
%python_alternative %{_bindir}/ikhal

%files -n python-khal-bash-completion
%{_datadir}/bash-completion/completions/khal

%files -n python-khal-fish-completion
%dir %{_datadir}/fish
%dir %{_datadir}/fish/vendor_completions.d
%{_datadir}/fish/vendor_completions.d/khal.fish

%files -n python-khal-zsh-completion
%dir %{_datadir}/zsh
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_khal

%changelog
* Wed Jul  2 2025 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.13.0:
  * icalendar >= 6.0.0 is now required.
* Mon Apr 14 2025 Danilo Spinella <danilo.spinella@suse.com>
- Update to 0.12.0:
  * FIX Don't install tests module.
- Update to 0.11.4:
  * optimization in ikhal when editing events in the far future or past
  * FIX an issue in ikhal with updating the view of the event list after editing
    an event
  * NEW properties of ikhal themes (dark and light) can now be overriden from the
    config file (via the new [palette] section, check the documenation)
  * NEW timedelta strings can now have a leading ``+``, e.g. ``+1d``
  * NEW Add ``--json`` option to output event data as JSON objects
  * NEW Add default alarms configuration option
  * FIX defaults for ``default_event_duration`` and ``default_dayevent_duration``
    where mixed up, ``default_dayevent_duration`` is the default for all-day events
  * NEW event format option ``status-symbol`` which represents the status of an
    event with a symbol (e.g. ``✓`` for confirmed, ``✗`` for cancelled, ``?`` for
    tentative)
  * NEW event format option ``partstat-symbol`` which represents the participation
    status of an event with a symbol (e.g. ``✓`` for accepted, ``✗`` for declined,
    ``?`` for tentative); partication status is shown for the email addresses
    configured for the event's calendar
  * NEW support for color theme, command, and formatter plugins
  * FIX an issue where ikhal would forget changes to time or date fields if you
    left the field with page up/down or meta+enter
  * CHANGE various UI improvments to ikhal.
  * FIX Deleting multiple of instances of a recurring event in ikhal
  * NEW Add ``enable_mouse`` configuration option.
* Mon Feb 12 2024 Matej Cepl <mcepl@cepl.eu>
- Update to 0.11.3:
  - FIX support urwid 2.4.2
* Thu Dec 28 2023 Dirk Müller <dmueller@suse.com>
- update to 0.11.2:
  * FIX khal `at` also uses `event_format` not
    `agenda_event_format`
  * FIX duplicating an event using `p` in ikhal
  * NEW Add ability to change the minimum number of months
    displayed with `min_calendar_display`
  * FIX ikhal don't crash when jumping long distances in time
  * FIX do not use urwid's private methods, would crash with
    latest urwid version
  * FIX light colorscheme in ikhal, would crash with recent urwid
    versions
  * FIX better error messages when we cannot import an event
  * FIX README.rst formatting to allow upload to PyPI
  * DROPPED support for python versions < 3.8
  * UPDATED REQUIREMENT pytz is now required >= 2018.7
  * NEW test REQUIREMENT: packaging
  * FIX support in tests for pytz version numbers of the format
    year.month.minor
  * FIX deleting of instances of recurring events in ikhal
  * FIX if a `discover` collection is set to "readonly",
    discovered collections will now inherit the readonly property
  * FIX ikhal will not wrap date headers into the next line in
    narrow terminals
  * FIX `configure` should only suggest valid default collection
    names
  * NEW the `configure` command can now set up vdirsyncer
  * NEW better error message for misuses of `at` and `list`
  * NEW `discover` collection type now supports `**` (arbitrary
    depths)
  * NEW Add testing for Python 3.11
- drop fix-pytz-tests.patch (upstream)
* Wed Dec 21 2022 Matej Cepl <mcepl@suse.com>
- Add generated shell completion scripts.
* Tue Dec 20 2022 Daniel Garcia <daniel.garcia@suse.com>
- Disable test_bogota and test_event_no_dst because are broken with the latests
  pytz versions
* Thu Oct  6 2022 Danilo Spinella <danilo.spinella@suse.com>
- Update to 0.10.5:
  * FIX support for tzlocal >= 4.0
  * FIX ability to show an event's calendar in ikhal
  * FIX an error logging for certain broken icalendar events that made ikhal crash
    after editing those events
  * NEW Add widget to interactive event editor that allows adding attendees as
    comma separated list of email addresses
  * FIX event creation for events after the second next DST transition
  * NEW Add support for Python 3.10
  * CHANGE search, at, and list don't print "No events" anymore if no matching
    events are found
  * NEW Add option to use multiple color only when not all calendar colors can
    be displayed.
- Add fix-pytz-tests.patch to fix tests with latest pytz version
* Tue Jan 11 2022 Dirk Müller <dmueller@suse.com>
- add python-rpm-macros
* Thu Aug 12 2021 Danilo Spinella <danilo.spinella@suse.com>
- Initial package
